@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/pysnmp/license.html
+# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# License: https://www.pysnmp.com/pysnmp/license.html
 #
 from pysnmp.proto.secmod.eso.priv import aesbase
 
@@ -10,8 +10,9 @@ from pysnmp.proto.secmod.eso.priv import aesbase
 class AesBlumenthal256(aesbase.AbstractAesBlumenthal):
     """AES 256 bit encryption (Internet draft)
 
-       http://tools.ietf.org/html/draft-blumenthal-aes-usm-04
+    http://tools.ietf.org/html/draft-blumenthal-aes-usm-04
     """
+
     serviceID = (1, 3, 6, 1, 4, 1, 9, 12, 6, 1, 2)  # cusmAESCfb256PrivProtocol
     keySize = 32
 
@@ -27,5 +28,18 @@ class Aes256(aesbase.AbstractAesReeder):
 
     Known to be used by many vendors including Cisco and others.
     """
-    serviceID = (1, 3, 6, 1, 4, 1, 9, 12, 6, 1, 102)  # cusmAESCfb256PrivProtocol (non-standard OID)
+
+    serviceID = (
+        1,
+        3,
+        6,
+        1,
+        4,
+        1,
+        9,
+        12,
+        6,
+        1,
+        102,
+    )  # cusmAESCfb256PrivProtocol (non-standard OID)
     keySize = 32
